@@ -77,6 +77,7 @@ main (int argc, char **argv)
 
   gchar *xauth_display = NULL;
   gchar *xauth_token = NULL;
+  gchar *sn_id = NULL;
 
   gchar buffer[255];
 
@@ -110,6 +111,13 @@ main (int argc, char **argv)
   fgets (buffer, 255, stdin);
   strip (buffer);
 
+  sn_id = g_strdup_printf ("%s", buffer + 10);
+  setenv("DESKTOP_STARTUP_ID", sn_id, TRUE);
+
+  bzero (buffer, 255);
+  fgets (buffer, 255, stdin);
+  strip (buffer);
+
   xauth_token = g_strdup_printf ("%s", buffer + 10);
 
   /* a bit more security is always fine */
