@@ -2681,6 +2681,9 @@ gksu_sudo_full (GksuContext *context,
 	  if (context->debug)
 	    fprintf (stderr, "No password prompt found; we'll assume we don't need a password.\n");
 
+          /* turn NONBLOCK off, also if have no prompt */
+          fcntl(parent_pipe[0], F_SETFL, fcntl(parent_pipe[0], F_GETFL) & ~O_NONBLOCK);
+
 	  should_display = gconf_client_get_bool (context->gconf_client,
 						  BASE_PATH "display-no-pass-info", NULL);
 
